Module: AgentPushKit
- Defined in:
- lib/agent_push_kit/version.rb,
lib/agent_push_kit.rb,
lib/agent_push_kit/api_error.rb,
lib/agent_push_kit/api_client.rb,
lib/agent_push_kit/models/user.rb,
lib/agent_push_kit/configuration.rb,
lib/agent_push_kit/models/device.rb,
lib/agent_push_kit/api/events_api.rb,
lib/agent_push_kit/api/health_api.rb,
lib/agent_push_kit/api_model_base.rb,
lib/agent_push_kit/models/service.rb,
lib/agent_push_kit/api/account_api.rb,
lib/agent_push_kit/api/devices_api.rb,
lib/agent_push_kit/models/event_page.rb,
lib/agent_push_kit/models/filter_not.rb,
lib/agent_push_kit/models/membership.rb,
lib/agent_push_kit/models/agent_token.rb,
lib/agent_push_kit/api/preferences_api.rb,
lib/agent_push_kit/models/event_detail.rb,
lib/agent_push_kit/models/event_filter.rb,
lib/agent_push_kit/models/filter_group.rb,
lib/agent_push_kit/models/organization.rb,
lib/agent_push_kit/api/agent_tokens_api.rb,
lib/agent_push_kit/models/auth_response.rb,
lib/agent_push_kit/models/event_summary.rb,
lib/agent_push_kit/models/type_override.rb,
lib/agent_push_kit/models/error_response.rb,
lib/agent_push_kit/models/register_input.rb,
lib/agent_push_kit/api/authentication_api.rb,
lib/agent_push_kit/models/api_key_summary.rb,
lib/agent_push_kit/models/current_account.rb,
lib/agent_push_kit/models/health_response.rb,
lib/agent_push_kit/models/membership_user.rb,
lib/agent_push_kit/models/service_summary.rb,
lib/agent_push_kit/models/add_member_input.rb,
lib/agent_push_kit/models/deleted_response.rb,
lib/agent_push_kit/models/delivery_summary.rb,
lib/agent_push_kit/models/ingestion_result.rb,
lib/agent_push_kit/models/revoked_response.rb,
lib/agent_push_kit/models/send_event_input.rb,
lib/agent_push_kit/models/accepted_response.rb,
lib/agent_push_kit/models/disabled_response.rb,
lib/agent_push_kit/models/preference_record.rb,
lib/agent_push_kit/models/set_enabled_input.rb,
lib/agent_push_kit/api/customer_accounts_api.rb,
lib/agent_push_kit/models/inherited_response.rb,
lib/agent_push_kit/models/organization_count.rb,
lib/agent_push_kit/models/service_preference.rb,
lib/agent_push_kit/models/agent_token_created.rb,
lib/agent_push_kit/models/organization_record.rb,
lib/agent_push_kit/models/search_events_input.rb,
lib/agent_push_kit/models/organization_created.rb,
lib/agent_push_kit/models/password_login_input.rb,
lib/agent_push_kit/models/provider_login_input.rb,
lib/agent_push_kit/models/service_all_of_count.rb,
lib/agent_push_kit/models/register_device_input.rb,
lib/agent_push_kit/models/text_filter_condition.rb,
lib/agent_push_kit/models/time_filter_condition.rb,
lib/agent_push_kit/models/web_push_subscription.rb,
lib/agent_push_kit/models/web_push_configuration.rb,
lib/agent_push_kit/models/create_agent_token_input.rb,
lib/agent_push_kit/models/create_organization_input.rb,
lib/agent_push_kit/models/organization_api_key_created.rb,
lib/agent_push_kit/models/password_reset_request_input.rb,
lib/agent_push_kit/models/password_reset_complete_input.rb,
lib/agent_push_kit/models/register_web_push_subscription_input.rb,
lib/agent_push_kit/models/register_web_push_subscription_input_keys.rb
Overview
#Agent Push Kit API
#The complete Agent Push Kit REST API. Application event ingestion uses an organization key beginning with apk_. Authenticated user operations accept either an Agent Push Kit login JWT or an agent access token beginning with apt_.
The version of the OpenAPI document: 0.1.0
Generated by: https://openapi-generator.tech Generator version: 7.24.0
Defined Under Namespace
Modules: EventFilter Classes: AcceptedResponse, AccountApi, AddMemberInput, AgentToken, AgentTokenCreated, AgentTokensApi, ApiClient, ApiError, ApiKeySummary, ApiModelBase, AuthResponse, AuthenticationApi, Configuration, CreateAgentTokenInput, CreateOrganizationInput, CurrentAccount, CustomerAccountsApi, DeletedResponse, DeliverySummary, Device, DevicesApi, DisabledResponse, ErrorResponse, EventDetail, EventPage, EventSummary, EventsApi, FilterGroup, FilterNot, HealthApi, HealthResponse, IngestionResult, InheritedResponse, Membership, MembershipUser, Organization, OrganizationApiKeyCreated, OrganizationCount, OrganizationCreated, OrganizationRecord, PasswordLoginInput, PasswordResetCompleteInput, PasswordResetRequestInput, PreferenceRecord, PreferencesApi, ProviderLoginInput, RegisterDeviceInput, RegisterInput, RegisterWebPushSubscriptionInput, RegisterWebPushSubscriptionInputKeys, RevokedResponse, SearchEventsInput, SendEventInput, Service, ServiceAllOfCount, ServicePreference, ServiceSummary, SetEnabledInput, TextFilterCondition, TimeFilterCondition, TypeOverride, User, WebPushConfiguration, WebPushSubscription
Constant Summary collapse
- VERSION =
'0.1.0'
Class Method Summary collapse
-
.configure ⇒ Object
Customize default settings for the SDK using block.
Class Method Details
.configure ⇒ Object
Customize default settings for the SDK using block. AgentPushKit.configure do |config| config.username = "xxx" config.password = "xxx" end If no block given, return the default Configuration object.
93 94 95 96 97 98 99 |
# File 'lib/agent_push_kit.rb', line 93 def configure if block_given? yield(Configuration.default) else Configuration.default end end |