Class: AgentPushKit::Device

Inherits:
ApiModelBase show all
Defined in:
lib/agent_push_kit/models/device.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Device

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/agent_push_kit/models/device.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AgentPushKit::Device` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AgentPushKit::Device`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'installation_id')
    self.installation_id = attributes[:'installation_id']
  else
    self.installation_id = nil
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  else
    self.environment = nil
  end

  if attributes.key?(:'app_version')
    self.app_version = attributes[:'app_version']
  else
    self.app_version = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'last_seen_at')
    self.last_seen_at = attributes[:'last_seen_at']
  else
    self.last_seen_at = nil
  end
end

Instance Attribute Details

#app_versionObject

Returns the value of attribute app_version.



24
25
26
# File 'lib/agent_push_kit/models/device.rb', line 24

def app_version
  @app_version
end

#enabledObject

Returns the value of attribute enabled.



26
27
28
# File 'lib/agent_push_kit/models/device.rb', line 26

def enabled
  @enabled
end

#environmentObject

Returns the value of attribute environment.



22
23
24
# File 'lib/agent_push_kit/models/device.rb', line 22

def environment
  @environment
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/agent_push_kit/models/device.rb', line 18

def id
  @id
end

#installation_idObject

Returns the value of attribute installation_id.



20
21
22
# File 'lib/agent_push_kit/models/device.rb', line 20

def installation_id
  @installation_id
end

#last_seen_atObject

Returns the value of attribute last_seen_at.



28
29
30
# File 'lib/agent_push_kit/models/device.rb', line 28

def last_seen_at
  @last_seen_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/agent_push_kit/models/device.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/agent_push_kit/models/device.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
# File 'lib/agent_push_kit/models/device.rb', line 53

def self.attribute_map
  {
    :'id' => :'id',
    :'installation_id' => :'installationId',
    :'environment' => :'environment',
    :'app_version' => :'appVersion',
    :'enabled' => :'enabled',
    :'last_seen_at' => :'lastSeenAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/agent_push_kit/models/device.rb', line 266

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
91
# File 'lib/agent_push_kit/models/device.rb', line 87

def self.openapi_nullable
  Set.new([
    :'app_version',
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
# File 'lib/agent_push_kit/models/device.rb', line 75

def self.openapi_types
  {
    :'id' => :'String',
    :'installation_id' => :'String',
    :'environment' => :'String',
    :'app_version' => :'String',
    :'enabled' => :'Boolean',
    :'last_seen_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



240
241
242
243
244
245
246
247
248
249
# File 'lib/agent_push_kit/models/device.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      installation_id == o.installation_id &&
      environment == o.environment &&
      app_version == o.app_version &&
      enabled == o.enabled &&
      last_seen_at == o.last_seen_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/agent_push_kit/models/device.rb', line 253

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



259
260
261
# File 'lib/agent_push_kit/models/device.rb', line 259

def hash
  [id, installation_id, environment, app_version, enabled, last_seen_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/agent_push_kit/models/device.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @installation_id.nil?
    invalid_properties.push('invalid value for "installation_id", installation_id cannot be nil.')
  end

  if @environment.nil?
    invalid_properties.push('invalid value for "environment", environment cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @last_seen_at.nil?
    invalid_properties.push('invalid value for "last_seen_at", last_seen_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/agent_push_kit/models/device.rb', line 288

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
182
183
184
185
186
# File 'lib/agent_push_kit/models/device.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @installation_id.nil?
  return false if @environment.nil?
  environment_validator = EnumAttributeValidator.new('String', ["SANDBOX", "PRODUCTION"])
  return false unless environment_validator.valid?(@environment)
  return false if @enabled.nil?
  return false if @last_seen_at.nil?
  true
end