Class: AgentPushKit::DevicesApi
- Inherits:
-
Object
- Object
- AgentPushKit::DevicesApi
- Defined in:
- lib/agent_push_kit/api/devices_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_web_push_configuration(opts = {}) ⇒ WebPushConfiguration
Get browser push availability and its public VAPID key.
-
#get_web_push_configuration_with_http_info(opts = {}) ⇒ Array<(WebPushConfiguration, Integer, Hash)>
Get browser push availability and its public VAPID key.
-
#initialize(api_client = ApiClient.default) ⇒ DevicesApi
constructor
A new instance of DevicesApi.
-
#register_device(register_device_input, opts = {}) ⇒ Device
Register or refresh an APNs device.
-
#register_device_with_http_info(register_device_input, opts = {}) ⇒ Array<(Device, Integer, Hash)>
Register or refresh an APNs device.
-
#register_web_push_subscription(register_web_push_subscription_input, opts = {}) ⇒ WebPushSubscription
Register or refresh a browser push subscription.
-
#register_web_push_subscription_with_http_info(register_web_push_subscription_input, opts = {}) ⇒ Array<(WebPushSubscription, Integer, Hash)>
Register or refresh a browser push subscription.
-
#remove_device(installation_id, opts = {}) ⇒ DisabledResponse
Disable push delivery to one installation.
-
#remove_device_with_http_info(installation_id, opts = {}) ⇒ Array<(DisabledResponse, Integer, Hash)>
Disable push delivery to one installation.
-
#remove_web_push_subscription(subscription_id, opts = {}) ⇒ DisabledResponse
Disable a browser push subscription.
-
#remove_web_push_subscription_with_http_info(subscription_id, opts = {}) ⇒ Array<(DisabledResponse, Integer, Hash)>
Disable a browser push subscription.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ DevicesApi
Returns a new instance of DevicesApi.
19 20 21 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_web_push_configuration(opts = {}) ⇒ WebPushConfiguration
Get browser push availability and its public VAPID key
25 26 27 28 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 25 def get_web_push_configuration(opts = {}) data, _status_code, _headers = get_web_push_configuration_with_http_info(opts) data end |
#get_web_push_configuration_with_http_info(opts = {}) ⇒ Array<(WebPushConfiguration, Integer, Hash)>
Get browser push availability and its public VAPID key
33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 33 def get_web_push_configuration_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DevicesApi.get_web_push_configuration ...' end # resource path local_var_path = '/web-push/configuration' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebPushConfiguration' # auth_names auth_names = opts[:debug_auth_names] || ['UserOrAgent'] = opts.merge( :operation => :"DevicesApi.get_web_push_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DevicesApi#get_web_push_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#register_device(register_device_input, opts = {}) ⇒ Device
Register or refresh an APNs device
81 82 83 84 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 81 def register_device(register_device_input, opts = {}) data, _status_code, _headers = register_device_with_http_info(register_device_input, opts) data end |
#register_device_with_http_info(register_device_input, opts = {}) ⇒ Array<(Device, Integer, Hash)>
Register or refresh an APNs device
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 90 def register_device_with_http_info(register_device_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DevicesApi.register_device ...' end # verify the required parameter 'register_device_input' is set if @api_client.config.client_side_validation && register_device_input.nil? fail ArgumentError, "Missing the required parameter 'register_device_input' when calling DevicesApi.register_device" end # resource path local_var_path = '/devices' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(register_device_input) # return_type return_type = opts[:debug_return_type] || 'Device' # auth_names auth_names = opts[:debug_auth_names] || ['UserOrAgent'] = opts.merge( :operation => :"DevicesApi.register_device", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DevicesApi#register_device\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#register_web_push_subscription(register_web_push_subscription_input, opts = {}) ⇒ WebPushSubscription
Register or refresh a browser push subscription
147 148 149 150 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 147 def register_web_push_subscription(register_web_push_subscription_input, opts = {}) data, _status_code, _headers = register_web_push_subscription_with_http_info(register_web_push_subscription_input, opts) data end |
#register_web_push_subscription_with_http_info(register_web_push_subscription_input, opts = {}) ⇒ Array<(WebPushSubscription, Integer, Hash)>
Register or refresh a browser push subscription
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 156 def register_web_push_subscription_with_http_info(register_web_push_subscription_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DevicesApi.register_web_push_subscription ...' end # verify the required parameter 'register_web_push_subscription_input' is set if @api_client.config.client_side_validation && register_web_push_subscription_input.nil? fail ArgumentError, "Missing the required parameter 'register_web_push_subscription_input' when calling DevicesApi.register_web_push_subscription" end # resource path local_var_path = '/web-push/subscriptions' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(register_web_push_subscription_input) # return_type return_type = opts[:debug_return_type] || 'WebPushSubscription' # auth_names auth_names = opts[:debug_auth_names] || ['UserOrAgent'] = opts.merge( :operation => :"DevicesApi.register_web_push_subscription", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DevicesApi#register_web_push_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_device(installation_id, opts = {}) ⇒ DisabledResponse
Disable push delivery to one installation
213 214 215 216 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 213 def remove_device(installation_id, opts = {}) data, _status_code, _headers = remove_device_with_http_info(installation_id, opts) data end |
#remove_device_with_http_info(installation_id, opts = {}) ⇒ Array<(DisabledResponse, Integer, Hash)>
Disable push delivery to one installation
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 222 def remove_device_with_http_info(installation_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DevicesApi.remove_device ...' end # verify the required parameter 'installation_id' is set if @api_client.config.client_side_validation && installation_id.nil? fail ArgumentError, "Missing the required parameter 'installation_id' when calling DevicesApi.remove_device" end if @api_client.config.client_side_validation && installation_id.to_s.length > 200 fail ArgumentError, 'invalid value for "installation_id" when calling DevicesApi.remove_device, the character length must be smaller than or equal to 200.' end if @api_client.config.client_side_validation && installation_id.to_s.length < 4 fail ArgumentError, 'invalid value for "installation_id" when calling DevicesApi.remove_device, the character length must be greater than or equal to 4.' end # resource path local_var_path = '/devices/{installationId}'.sub('{installationId}', CGI.escape(installation_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DisabledResponse' # auth_names auth_names = opts[:debug_auth_names] || ['UserOrAgent'] = opts.merge( :operation => :"DevicesApi.remove_device", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DevicesApi#remove_device\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_web_push_subscription(subscription_id, opts = {}) ⇒ DisabledResponse
Disable a browser push subscription
282 283 284 285 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 282 def remove_web_push_subscription(subscription_id, opts = {}) data, _status_code, _headers = remove_web_push_subscription_with_http_info(subscription_id, opts) data end |
#remove_web_push_subscription_with_http_info(subscription_id, opts = {}) ⇒ Array<(DisabledResponse, Integer, Hash)>
Disable a browser push subscription
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/agent_push_kit/api/devices_api.rb', line 291 def remove_web_push_subscription_with_http_info(subscription_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DevicesApi.remove_web_push_subscription ...' end # verify the required parameter 'subscription_id' is set if @api_client.config.client_side_validation && subscription_id.nil? fail ArgumentError, "Missing the required parameter 'subscription_id' when calling DevicesApi.remove_web_push_subscription" end # resource path local_var_path = '/web-push/subscriptions/{subscriptionId}'.sub('{subscriptionId}', CGI.escape(subscription_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DisabledResponse' # auth_names auth_names = opts[:debug_auth_names] || ['UserOrAgent'] = opts.merge( :operation => :"DevicesApi.remove_web_push_subscription", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DevicesApi#remove_web_push_subscription\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |