Class: AgentPushKit::EventDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AgentPushKit::EventDetail
- Defined in:
- lib/agent_push_kit/models/event_detail.rb
Instance Attribute Summary collapse
-
#action_url ⇒ Object
Returns the value of attribute action_url.
-
#body ⇒ Object
Returns the value of attribute body.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#id ⇒ Object
Returns the value of attribute id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#service ⇒ Object
Returns the value of attribute service.
-
#service_id ⇒ Object
Returns the value of attribute service_id.
-
#title ⇒ Object
Returns the value of attribute title.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EventDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EventDetail
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AgentPushKit::EventDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AgentPushKit::EventDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'body') self.body = attributes[:'body'] else self.body = nil end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] else self.external_id = nil end if attributes.key?(:'action_url') self.action_url = attributes[:'action_url'] else self.action_url = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'service') self.service = attributes[:'service'] else self.service = nil end if attributes.key?(:'service_id') self.service_id = attributes[:'service_id'] else self.service_id = nil end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end else self. = nil end end |
Instance Attribute Details
#action_url ⇒ Object
Returns the value of attribute action_url.
28 29 30 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 28 def action_url @action_url end |
#body ⇒ Object
Returns the value of attribute body.
24 25 26 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 24 def body @body end |
#created_at ⇒ Object
Returns the value of attribute created_at.
30 31 32 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 30 def created_at @created_at end |
#external_id ⇒ Object
Returns the value of attribute external_id.
26 27 28 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 26 def external_id @external_id end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 18 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
36 37 38 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 36 def @metadata end |
#service ⇒ Object
Returns the value of attribute service.
32 33 34 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 32 def service @service end |
#service_id ⇒ Object
Returns the value of attribute service_id.
34 35 36 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 34 def service_id @service_id end |
#title ⇒ Object
Returns the value of attribute title.
22 23 24 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 22 def title @title end |
#type ⇒ Object
Returns the value of attribute type.
20 21 22 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 20 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 39 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'title' => :'title', :'body' => :'body', :'external_id' => :'externalId', :'action_url' => :'actionUrl', :'created_at' => :'createdAt', :'service' => :'service', :'service_id' => :'serviceId', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 355 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
88 89 90 91 92 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 88 def self.openapi_all_of [ :'EventSummary' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 81 def self.openapi_nullable Set.new([ :'metadata' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 65 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'title' => :'String', :'body' => :'String', :'external_id' => :'String', :'action_url' => :'String', :'created_at' => :'Time', :'service' => :'ServiceSummary', :'service_id' => :'String', :'metadata' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 325 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && title == o.title && body == o.body && external_id == o.external_id && action_url == o.action_url && created_at == o.created_at && service == o.service && service_id == o.service_id && == o. end |
#eql?(o) ⇒ Boolean
342 343 344 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 342 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
348 349 350 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 348 def hash [id, type, title, body, external_id, action_url, created_at, service, service_id, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @body.nil? invalid_properties.push('invalid value for "body", body cannot be nil.') end if @external_id.nil? invalid_properties.push('invalid value for "external_id", external_id cannot be nil.') end if @action_url.nil? invalid_properties.push('invalid value for "action_url", action_url cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @service.nil? invalid_properties.push('invalid value for "service", service cannot be nil.') end if @service_id.nil? invalid_properties.push('invalid value for "service_id", service_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/agent_push_kit/models/event_detail.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @title.nil? return false if @body.nil? return false if @external_id.nil? return false if @action_url.nil? return false if @created_at.nil? return false if @service.nil? return false if @service_id.nil? true end |