Class: AgentPushKit::OrganizationApiKeyCreated

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/agent_push_kit/models/organization_api_key_created.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OrganizationApiKeyCreated

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AgentPushKit::OrganizationApiKeyCreated` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AgentPushKit::OrganizationApiKeyCreated`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key_prefix')
    self.key_prefix = attributes[:'key_prefix']
  else
    self.key_prefix = nil
  end

  if attributes.key?(:'last_four')
    self.last_four = attributes[:'last_four']
  else
    self.last_four = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'api_key')
    self.api_key = attributes[:'api_key']
  else
    self.api_key = nil
  end
end

Instance Attribute Details

#api_keyObject

Returns the value of attribute api_key.



24
25
26
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 24

def api_key
  @api_key
end

#key_prefixObject

Returns the value of attribute key_prefix.



18
19
20
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 18

def key_prefix
  @key_prefix
end

#last_fourObject

Returns the value of attribute last_four.



20
21
22
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 20

def last_four
  @last_four
end

#updated_atObject

Returns the value of attribute updated_at.



22
23
24
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 22

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
34
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 27

def self.attribute_map
  {
    :'key_prefix' => :'keyPrefix',
    :'last_four' => :'lastFour',
    :'updated_at' => :'updatedAt',
    :'api_key' => :'apiKey'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
54
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 47

def self.openapi_types
  {
    :'key_prefix' => :'String',
    :'last_four' => :'String',
    :'updated_at' => :'Time',
    :'api_key' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key_prefix == o.key_prefix &&
      last_four == o.last_four &&
      updated_at == o.updated_at &&
      api_key == o.api_key
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 202

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



208
209
210
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 208

def hash
  [key_prefix, last_four, updated_at, api_key].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key_prefix.nil?
    invalid_properties.push('invalid value for "key_prefix", key_prefix cannot be nil.')
  end

  if @last_four.nil?
    invalid_properties.push('invalid value for "last_four", last_four cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @api_key.nil?
    invalid_properties.push('invalid value for "api_key", api_key cannot be nil.')
  end

  pattern = Regexp.new(/^apk_/)
  if @api_key !~ pattern
    invalid_properties.push("invalid value for \"api_key\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
138
139
140
141
142
# File 'lib/agent_push_kit/models/organization_api_key_created.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key_prefix.nil?
  return false if @last_four.nil?
  return false if @updated_at.nil?
  return false if @api_key.nil?
  return false if @api_key !~ Regexp.new(/^apk_/)
  true
end