Class: AgentPushKit::SendEventInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AgentPushKit::SendEventInput
- Defined in:
- lib/agent_push_kit/models/send_event_input.rb
Instance Attribute Summary collapse
-
#action_url ⇒ Object
Returns the value of attribute action_url.
-
#body ⇒ Object
Returns the value of attribute body.
-
#external_id ⇒ Object
Returns the value of attribute external_id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#service ⇒ Object
Returns the value of attribute service.
-
#service_display_name ⇒ Object
Returns the value of attribute service_display_name.
-
#title ⇒ Object
Returns the value of attribute title.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendEventInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendEventInput
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AgentPushKit::SendEventInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AgentPushKit::SendEventInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'service') self.service = attributes[:'service'] else self.service = nil end if attributes.key?(:'service_display_name') self.service_display_name = attributes[:'service_display_name'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'body') self.body = attributes[:'body'] else self.body = nil end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'action_url') self.action_url = attributes[:'action_url'] end end |
Instance Attribute Details
#action_url ⇒ Object
Returns the value of attribute action_url.
32 33 34 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 32 def action_url @action_url end |
#body ⇒ Object
Returns the value of attribute body.
26 27 28 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 26 def body @body end |
#external_id ⇒ Object
Returns the value of attribute external_id.
30 31 32 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 30 def external_id @external_id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
28 29 30 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 28 def @metadata end |
#service ⇒ Object
Returns the value of attribute service.
18 19 20 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 18 def service @service end |
#service_display_name ⇒ Object
Returns the value of attribute service_display_name.
20 21 22 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 20 def service_display_name @service_display_name end |
#title ⇒ Object
Returns the value of attribute title.
24 25 26 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 24 def title @title end |
#type ⇒ Object
Returns the value of attribute type.
22 23 24 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 22 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 35 def self.attribute_map { :'service' => :'service', :'service_display_name' => :'serviceDisplayName', :'type' => :'type', :'title' => :'title', :'body' => :'body', :'metadata' => :'metadata', :'external_id' => :'externalId', :'action_url' => :'actionUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 389 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 59 def self.openapi_types { :'service' => :'String', :'service_display_name' => :'String', :'type' => :'String', :'title' => :'String', :'body' => :'String', :'metadata' => :'Hash<String, Object>', :'external_id' => :'String', :'action_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 361 def ==(o) return true if self.equal?(o) self.class == o.class && service == o.service && service_display_name == o.service_display_name && type == o.type && title == o.title && body == o.body && == o. && external_id == o.external_id && action_url == o.action_url end |
#eql?(o) ⇒ Boolean
376 377 378 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 376 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
382 383 384 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 382 def hash [service, service_display_name, type, title, body, , external_id, action_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 139 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @service.nil? invalid_properties.push('invalid value for "service", service cannot be nil.') end if @service.to_s.length > 120 invalid_properties.push('invalid value for "service", the character length must be smaller than or equal to 120.') end if @service.to_s.length < 1 invalid_properties.push('invalid value for "service", the character length must be greater than or equal to 1.') end if !@service_display_name.nil? && @service_display_name.to_s.length > 120 invalid_properties.push('invalid value for "service_display_name", the character length must be smaller than or equal to 120.') end if !@service_display_name.nil? && @service_display_name.to_s.length < 1 invalid_properties.push('invalid value for "service_display_name", the character length must be greater than or equal to 1.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @type.to_s.length > 120 invalid_properties.push('invalid value for "type", the character length must be smaller than or equal to 120.') end if @type.to_s.length < 1 invalid_properties.push('invalid value for "type", the character length must be greater than or equal to 1.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @title.to_s.length > 200 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 200.') end if @title.to_s.length < 1 invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.') end if @body.nil? invalid_properties.push('invalid value for "body", body cannot be nil.') end if @body.to_s.length > 10000 invalid_properties.push('invalid value for "body", the character length must be smaller than or equal to 10000.') end if @body.to_s.length < 1 invalid_properties.push('invalid value for "body", the character length must be greater than or equal to 1.') end if !@external_id.nil? && @external_id.to_s.length > 300 invalid_properties.push('invalid value for "external_id", the character length must be smaller than or equal to 300.') end if !@external_id.nil? && @external_id.to_s.length < 1 invalid_properties.push('invalid value for "external_id", the character length must be greater than or equal to 1.') end if !@action_url.nil? && @action_url.to_s.length > 2000 invalid_properties.push('invalid value for "action_url", the character length must be smaller than or equal to 2000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 411 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/agent_push_kit/models/send_event_input.rb', line 215 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @service.nil? return false if @service.to_s.length > 120 return false if @service.to_s.length < 1 return false if !@service_display_name.nil? && @service_display_name.to_s.length > 120 return false if !@service_display_name.nil? && @service_display_name.to_s.length < 1 return false if @type.nil? return false if @type.to_s.length > 120 return false if @type.to_s.length < 1 return false if @title.nil? return false if @title.to_s.length > 200 return false if @title.to_s.length < 1 return false if @body.nil? return false if @body.to_s.length > 10000 return false if @body.to_s.length < 1 return false if !@external_id.nil? && @external_id.to_s.length > 300 return false if !@external_id.nil? && @external_id.to_s.length < 1 return false if !@action_url.nil? && @action_url.to_s.length > 2000 true end |