Class: AgentPushKit::User

Inherits:
ApiModelBase show all
Defined in:
lib/agent_push_kit/models/user.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ User

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/agent_push_kit/models/user.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `AgentPushKit::User` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `AgentPushKit::User`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  else
    self.display_name = nil
  end

  if attributes.key?(:'has_password')
    self.has_password = attributes[:'has_password']
  else
    self.has_password = nil
  end

  if attributes.key?(:'has_google')
    self.has_google = attributes[:'has_google']
  else
    self.has_google = nil
  end

  if attributes.key?(:'has_apple')
    self.has_apple = attributes[:'has_apple']
  else
    self.has_apple = nil
  end
end

Instance Attribute Details

#display_nameObject

Returns the value of attribute display_name.



22
23
24
# File 'lib/agent_push_kit/models/user.rb', line 22

def display_name
  @display_name
end

#emailObject

Returns the value of attribute email.



20
21
22
# File 'lib/agent_push_kit/models/user.rb', line 20

def email
  @email
end

#has_appleObject

Returns the value of attribute has_apple.



28
29
30
# File 'lib/agent_push_kit/models/user.rb', line 28

def has_apple
  @has_apple
end

#has_googleObject

Returns the value of attribute has_google.



26
27
28
# File 'lib/agent_push_kit/models/user.rb', line 26

def has_google
  @has_google
end

#has_passwordObject

Returns the value of attribute has_password.



24
25
26
# File 'lib/agent_push_kit/models/user.rb', line 24

def has_password
  @has_password
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/agent_push_kit/models/user.rb', line 18

def id
  @id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/agent_push_kit/models/user.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/agent_push_kit/models/user.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/agent_push_kit/models/user.rb', line 31

def self.attribute_map
  {
    :'id' => :'id',
    :'email' => :'email',
    :'display_name' => :'displayName',
    :'has_password' => :'hasPassword',
    :'has_google' => :'hasGoogle',
    :'has_apple' => :'hasApple'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/agent_push_kit/models/user.rb', line 242

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
# File 'lib/agent_push_kit/models/user.rb', line 65

def self.openapi_nullable
  Set.new([
    :'display_name',
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/agent_push_kit/models/user.rb', line 53

def self.openapi_types
  {
    :'id' => :'String',
    :'email' => :'String',
    :'display_name' => :'String',
    :'has_password' => :'Boolean',
    :'has_google' => :'Boolean',
    :'has_apple' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



216
217
218
219
220
221
222
223
224
225
# File 'lib/agent_push_kit/models/user.rb', line 216

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      email == o.email &&
      display_name == o.display_name &&
      has_password == o.has_password &&
      has_google == o.has_google &&
      has_apple == o.has_apple
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/agent_push_kit/models/user.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/agent_push_kit/models/user.rb', line 235

def hash
  [id, email, display_name, has_password, has_google, has_apple].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/agent_push_kit/models/user.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @has_password.nil?
    invalid_properties.push('invalid value for "has_password", has_password cannot be nil.')
  end

  if @has_google.nil?
    invalid_properties.push('invalid value for "has_google", has_google cannot be nil.')
  end

  if @has_apple.nil?
    invalid_properties.push('invalid value for "has_apple", has_apple cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/agent_push_kit/models/user.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
161
162
# File 'lib/agent_push_kit/models/user.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @email.nil?
  return false if @has_password.nil?
  return false if @has_google.nil?
  return false if @has_apple.nil?
  true
end