Class: AgentPushKit::AgentTokenCreated
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- AgentPushKit::AgentTokenCreated
- Defined in:
- lib/agent_push_kit/models/agent_token_created.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#key_prefix ⇒ Object
Returns the value of attribute key_prefix.
-
#last_four ⇒ Object
Returns the value of attribute last_four.
-
#last_used_at ⇒ Object
Returns the value of attribute last_used_at.
-
#name ⇒ Object
Returns the value of attribute name.
-
#revoked_at ⇒ Object
Returns the value of attribute revoked_at.
-
#token ⇒ Object
Returns the value of attribute token.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AgentTokenCreated
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AgentTokenCreated
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `AgentPushKit::AgentTokenCreated` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `AgentPushKit::AgentTokenCreated`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'key_prefix') self.key_prefix = attributes[:'key_prefix'] else self.key_prefix = nil end if attributes.key?(:'last_four') self.last_four = attributes[:'last_four'] else self.last_four = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'last_used_at') self.last_used_at = attributes[:'last_used_at'] else self.last_used_at = nil end if attributes.key?(:'revoked_at') self.revoked_at = attributes[:'revoked_at'] else self.revoked_at = nil end if attributes.key?(:'token') self.token = attributes[:'token'] else self.token = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
26 27 28 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 26 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 18 def id @id end |
#key_prefix ⇒ Object
Returns the value of attribute key_prefix.
22 23 24 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 22 def key_prefix @key_prefix end |
#last_four ⇒ Object
Returns the value of attribute last_four.
24 25 26 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 24 def last_four @last_four end |
#last_used_at ⇒ Object
Returns the value of attribute last_used_at.
28 29 30 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 28 def last_used_at @last_used_at end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 20 def name @name end |
#revoked_at ⇒ Object
Returns the value of attribute revoked_at.
30 31 32 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 30 def revoked_at @revoked_at end |
#token ⇒ Object
Returns the value of attribute token.
32 33 34 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 32 def token @token end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 35 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'key_prefix' => :'keyPrefix', :'last_four' => :'lastFour', :'created_at' => :'createdAt', :'last_used_at' => :'lastUsedAt', :'revoked_at' => :'revokedAt', :'token' => :'token' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 326 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
79 80 81 82 83 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 79 def self.openapi_all_of [ :'AgentToken' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 59 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'key_prefix' => :'String', :'last_four' => :'String', :'created_at' => :'Time', :'last_used_at' => :'Time', :'revoked_at' => :'Time', :'token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 298 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && key_prefix == o.key_prefix && last_four == o.last_four && created_at == o.created_at && last_used_at == o.last_used_at && revoked_at == o.revoked_at && token == o.token end |
#eql?(o) ⇒ Boolean
313 314 315 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 313 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
319 320 321 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 319 def hash [id, name, key_prefix, last_four, created_at, last_used_at, revoked_at, token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @key_prefix.nil? invalid_properties.push('invalid value for "key_prefix", key_prefix cannot be nil.') end if @last_four.nil? invalid_properties.push('invalid value for "last_four", last_four cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @last_used_at.nil? invalid_properties.push('invalid value for "last_used_at", last_used_at cannot be nil.') end if @revoked_at.nil? invalid_properties.push('invalid value for "revoked_at", revoked_at cannot be nil.') end if @token.nil? invalid_properties.push('invalid value for "token", token cannot be nil.') end pattern = Regexp.new(/^apt_/) if @token !~ pattern invalid_properties.push("invalid value for \"token\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 348 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/agent_push_kit/models/agent_token_created.rb', line 197 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @key_prefix.nil? return false if @last_four.nil? return false if @created_at.nil? return false if @last_used_at.nil? return false if @revoked_at.nil? return false if @token.nil? return false if @token !~ Regexp.new(/^apt_/) true end |